@@ -38,8 +38,7 @@ class BaseOS(object):
     @classmethod
     def _get_subclasses(cls):
         for subclass in cls.__subclasses__():
-            for sc in subclass._get_subclasses():
-                yield sc
+            yield from subclass._get_subclasses()
             yield subclass
 
     @classmethod
@@ -65,14 +64,15 @@ class BaseOS(object):
         interface.write()
 
     def write_vip_interface_file(self, interface, vips, mtu, vrrp_info,
-                                 fixed_ips=None):
+                                 fixed_ips=None, is_sriov=False):
         vip_interface = interface_file.VIPInterfaceFile(
             name=interface,
             mtu=mtu,
             vips=vips,
             vrrp_info=vrrp_info,
             fixed_ips=fixed_ips,
-            topology=CONF.controller_worker.loadbalancer_topology)
+            topology=CONF.controller_worker.loadbalancer_topology,
+            is_sriov=is_sriov)
         vip_interface.write()
 
     def write_port_interface_file(self, interface, fixed_ips, mtu):
@@ -116,7 +116,7 @@ class RH(BaseOS):
 
     @classmethod
     def is_os_name(cls, os_name):
-        return os_name in ['fedora', 'rhel']
+        return os_name in ['fedora', 'rhel', 'rocky']
 
     def cmd_get_version_of_installed_package(self, package_name):
         name = self._map_package_name(package_name)
