@@ -24,7 +24,7 @@ LOG = logging.getLogger(__name__)
 
 
 def round_robin_addr(addrinfo_list):
-    if len(addrinfo_list) <= 0:
+    if not addrinfo_list:
         return None
     addrinfo = addrinfo_list.pop(0)
     addrinfo_list.append(addrinfo)
@@ -70,6 +70,8 @@ class UDPStatusSender(object):
         for ipport in CONF.health_manager.controller_ip_port_list:
             try:
                 ip, port = ipport.rsplit(':', 1)
+                if ip and ip[0] == '[' and ip[-1] == ']':
+                    ip = ip[1:-1]
             except ValueError:
                 LOG.error("Invalid ip and port '%s' in health_manager "
                           "controller_ip_port_list", ipport)
