@@ -111,6 +111,11 @@ class HaproxyAmphoraLoadBalancerDriver(
 
         return api_version
 
+    def check(self, amphora: db_models.Amphora,
+              timeout_dict: Optional[dict] = None):
+        """Check connectivity to the amphora."""
+        self._populate_amphora_api_version(amphora, timeout_dict)
+
     def update_amphora_listeners(self, loadbalancer, amphora,
                                  timeout_dict=None):
         """Update the amphora with a new configuration.
@@ -313,7 +318,7 @@ class HaproxyAmphoraLoadBalancerDriver(
             # We have other listeners, so just update is fine.
             # TODO(rm_work): This is a little inefficient since this duplicates
             # a lot of the detection logic that has already been done, but it
-            # is probably safer to re-use the existing code-path.
+            # is probably safer to reuse the existing code-path.
             self.update_amphora_listeners(listener.load_balancer, amphora)
         else:
             # Deleting the last listener, so really do the delete
@@ -335,7 +340,7 @@ class HaproxyAmphoraLoadBalancerDriver(
     def finalize_amphora(self, amphora):
         pass
 
-    def _build_net_info(self, port, amphora, subnet, mtu=None):
+    def _build_net_info(self, port, amphora, subnet, mtu=None, sriov=False):
         # NOTE(blogan): using the vrrp port here because that
         # is what the allowed address pairs network driver sets
         # this particular port to.  This does expose a bit of
@@ -354,7 +359,8 @@ class HaproxyAmphoraLoadBalancerDriver(
                     'vrrp_ip': amphora[consts.VRRP_IP],
                     'mtu': mtu or port[consts.NETWORK][consts.MTU],
                     'host_routes': host_routes,
-                    'additional_vips': []}
+                    'additional_vips': [],
+                    'is_sriov': sriov}
         return net_info
 
     def post_vip_plug(self, amphora, load_balancer, amphorae_network_config,
@@ -365,9 +371,12 @@ class HaproxyAmphoraLoadBalancerDriver(
             mtu = port[consts.NETWORK][consts.MTU]
             LOG.debug("Post-VIP-Plugging with vrrp_ip %s vrrp_port %s",
                       amphora.vrrp_ip, port[consts.ID])
+            sriov = False
+            if load_balancer.vip.vnic_type == consts.VNIC_TYPE_DIRECT:
+                sriov = True
             net_info = self._build_net_info(
                 port, amphora.to_dict(),
-                vip_subnet.to_dict(recurse=True), mtu)
+                vip_subnet.to_dict(recurse=True), mtu, sriov)
             for add_vip in additional_vip_data:
                 add_host_routes = [{'nexthop': hr.nexthop,
                                     'destination': hr.destination}
@@ -579,15 +588,33 @@ class HaproxyAmphoraLoadBalancerDriver(
                              req_read_timeout, conn_max_retries,
                              conn_retry_interval
         :type timeout_dict: dict
-        :returns: None if not found, the interface name string if found.
+        :returns: the interface name string if found.
+        :raises octavia.amphorae.drivers.haproxy.exceptions.NotFound:
+                No interface found on the amphora
+        :raises TimeOutException: The amphora didn't reply
+        """
+        self._populate_amphora_api_version(amphora, timeout_dict)
+        response_json = self.clients[amphora.api_version].get_interface(
+            amphora, ip_address, timeout_dict, log_error=False)
+        return response_json.get('interface', None)
+
+    def set_interface_rules(self, amphora: db_models.Amphora,
+                            ip_address, rules, timeout_dict=None):
+        """Sets interface firewall rules in the amphora
+
+        :param amphora: The amphora to query.
+        :param ip_address: The IP address assigned to the interface the rules
+                           will be applied on.
+        :param rules: The l1st of allow rules to apply.
         """
         try:
             self._populate_amphora_api_version(amphora, timeout_dict)
-            response_json = self.clients[amphora.api_version].get_interface(
-                amphora, ip_address, timeout_dict, log_error=False)
-            return response_json.get('interface', None)
-        except (exc.NotFound, driver_except.TimeOutException):
-            return None
+            self.clients[amphora.api_version].set_interface_rules(
+                amphora, ip_address, rules, timeout_dict=timeout_dict)
+        except exc.NotFound as e:
+            LOG.debug('Amphora %s does not support the set_interface_rules '
+                      'API.', amphora.id)
+            raise driver_except.AmpDriverNotImplementedError() from e
 
 
 # Check a custom hostname
@@ -858,3 +885,8 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
     def update_agent_config(self, amp, agent_config, timeout_dict=None):
         r = self.put(amp, 'config', timeout_dict, data=agent_config)
         return exc.check_exception(r)
+
+    def set_interface_rules(self, amp, ip_address, rules, timeout_dict=None):
+        r = self.put(amp, f'interface/{ip_address}/rules', timeout_dict,
+                     json=rules)
+        return exc.check_exception(r)
