@@ -106,10 +106,16 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
                 operator_fault_string=msg)
 
     # Load Balancer
-    def create_vip_port(self, loadbalancer_id, project_id, vip_dictionary):
+    def create_vip_port(self, loadbalancer_id, project_id, vip_dictionary,
+                        additional_vip_dicts):
         vip_obj = driver_utils.provider_vip_dict_to_vip_obj(vip_dictionary)
+        add_vip_objs = [
+            driver_utils.provider_additional_vip_dict_to_additional_vip_obj(
+                add_vip)
+            for add_vip in additional_vip_dicts]
         lb_obj = data_models.LoadBalancer(id=loadbalancer_id,
-                                          project_id=project_id, vip=vip_obj)
+                                          project_id=project_id, vip=vip_obj,
+                                          additional_vips=add_vip_objs)
 
         network_driver = utils.get_network_driver()
         vip_network = network_driver.get_network(
@@ -120,7 +126,7 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
                                          operator_fault_string=message)
 
         try:
-            vip = network_driver.allocate_vip(lb_obj)
+            vip, add_vips = network_driver.allocate_vip(lb_obj)
         except network_base.AllocateVIPException as e:
             message = str(e)
             if getattr(e, 'orig_msg', None) is not None:
@@ -130,7 +136,10 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
         LOG.info('Amphora provider created VIP port %s for load balancer %s.',
                  vip.port_id, loadbalancer_id)
-        return driver_utils.vip_dict_to_provider_dict(vip.to_dict())
+        vip_return_dict = driver_utils.vip_dict_to_provider_dict(vip.to_dict())
+        add_return_dicts = [driver_utils.additional_vip_dict_to_provider_dict(
+            add_vip.to_dict()) for add_vip in add_vips]
+        return vip_return_dict, add_return_dicts
 
     # TODO(johnsom) convert this to octavia_lib constant flavor
     # once octavia is transitioned to use octavia_lib
@@ -264,8 +273,10 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
     # Member
     def member_create(self, member):
         pool_id = member.pool_id
-        db_pool = self.repositories.pool.get(db_apis.get_session(),
-                                             id=pool_id)
+        session = db_apis.get_session()
+        with session.begin():
+            db_pool = self.repositories.pool.get(session,
+                                                 id=pool_id)
         self._validate_members(db_pool, [member])
 
         payload = {consts.MEMBER: member.to_dict()}
@@ -287,7 +298,9 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     def member_batch_update(self, pool_id, members):
         # The DB should not have updated yet, so we can still use the pool
-        db_pool = self.repositories.pool.get(db_apis.get_session(), id=pool_id)
+        session = db_apis.get_session()
+        with session.begin():
+            db_pool = self.repositories.pool.get(session, id=pool_id)
 
         self._validate_members(db_pool, members)
 
@@ -325,15 +338,23 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     def _validate_members(self, db_pool, members):
         if db_pool.protocol in consts.LVS_PROTOCOLS:
-            # For SCTP/UDP LBs, check that we are not mixing IPv4 and IPv6
+            # For SCTP/UDP LBs:
+            # Allow ipv4 member if there's at least one ipv4 VIP
+            # Allow ipv6 member if there's at least one ipv6 VIP
             for member in members:
                 member_is_ipv6 = utils.is_ipv6(member.address)
 
                 for listener in db_pool.listeners:
                     lb = listener.load_balancer
-                    vip_is_ipv6 = utils.is_ipv6(lb.vip.ip_address)
+                    vips = [lb.vip]
+                    vips.extend(lb.additional_vips)
+                    lb_has_ipv4 = any(utils.is_ipv4(vip.ip_address)
+                                      for vip in vips)
+                    lb_has_ipv6 = any(utils.is_ipv6(vip.ip_address)
+                                      for vip in vips)
 
-                    if member_is_ipv6 != vip_is_ipv6:
+                    if ((member_is_ipv6 and not lb_has_ipv6) or
+                            (not member_is_ipv6 and not lb_has_ipv4)):
                         msg = ("This provider doesn't support mixing IPv4 and "
                                "IPv6 addresses for its VIP and members in {} "
                                "load balancers.".format(db_pool.protocol))
@@ -368,8 +389,10 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     # L7 Policy
     def l7policy_create(self, l7policy):
-        db_listener = self.repositories.listener.get(db_apis.get_session(),
-                                                     id=l7policy.listener_id)
+        session = db_apis.get_session()
+        with session.begin():
+            db_listener = self.repositories.listener.get(
+                session, id=l7policy.listener_id)
         if db_listener.protocol not in VALID_L7POLICY_LISTENER_PROTOCOLS:
             msg = ('%s protocol listeners do not support L7 policies' % (
                 db_listener.protocol))
