@@ -21,7 +21,6 @@ import abc
 
 from barbicanclient.v1 import containers
 from oslo_utils import encodeutils
-import six
 
 from octavia.certificates.common import cert
 from octavia.common.tls_utils import cert_parser
@@ -46,8 +45,7 @@ class BarbicanCert(cert.Cert):
         if self._cert_container.intermediates:
             intermediates = encodeutils.to_utf8(
                 self._cert_container.intermediates.payload)
-            return [imd for imd in cert_parser.get_intermediates_pems(
-                intermediates)]
+            return list(cert_parser.get_intermediates_pems(intermediates))
         return None
 
     def get_private_key(self):
@@ -63,8 +61,7 @@ class BarbicanCert(cert.Cert):
         return None
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BarbicanAuth(object):
+class BarbicanAuth(object, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def get_barbican_client(self, project_id):
         """Creates a Barbican client object.
