@@ -50,9 +50,9 @@ class LocalCertManager(cert_mgr.CertManager):
         """
         cert_ref = str(uuid.uuid4())
         filename_base = os.path.join(CONF.certificates.storage_path, cert_ref)
-        if type(certificate) == bytes:
+        if isinstance(certificate, bytes):
             certificate = certificate.decode('utf-8')
-        if type(private_key) == bytes:
+        if isinstance(private_key, bytes):
             private_key = private_key.decode('utf-8')
 
         LOG.info("Storing certificate data on the local filesystem.")
@@ -71,7 +71,7 @@ class LocalCertManager(cert_mgr.CertManager):
 
             if intermediates:
                 filename_intermediates = "{0}.int".format(filename_base)
-                if type(intermediates) == bytes:
+                if isinstance(intermediates, bytes):
                     intermediates = intermediates.decode('utf-8')
                 with os.fdopen(os.open(
                         filename_intermediates, flags, mode), 'w') as int_file:
@@ -79,7 +79,7 @@ class LocalCertManager(cert_mgr.CertManager):
 
             if private_key_passphrase:
                 filename_pkp = "{0}.pass".format(filename_base)
-                if type(private_key_passphrase) == bytes:
+                if isinstance(private_key_passphrase, bytes):
                     private_key_passphrase = private_key_passphrase.decode(
                         'utf-8')
                 with os.fdopen(os.open(
