@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 #    Copyright 2022 Red Hat
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -19,11 +18,10 @@
 # of metrics. It also aligns the terms to be consistent with Octavia
 # terminology.
 
-from http.server import HTTPServer
 from http.server import SimpleHTTPRequestHandler
+from http.server import ThreadingHTTPServer
 import os
 import signal
-import socketserver
 import sys
 import threading
 import time
@@ -398,7 +396,7 @@ METRIC_MAP = {
         ("octavia_pool_client_aborts_total{", None, {"proxy=": "pool="}),
     "haproxy_backend_server_aborts_total ":
         ("octavia_pool_member_aborts_total ",
-         "# HELP octavia_pool_server_aborts_total Total number of data "
+         "# HELP octavia_pool_member_aborts_total Total number of data "
          "transfers aborted by the server.\n", None),
     "haproxy_backend_server_aborts_total{":
         ("octavia_pool_member_aborts_total{", None, {"proxy=": "pool="}),
@@ -785,12 +783,6 @@ def shutdown_thread(http):
     http.shutdown()
 
 
-# TODO(johnsom) Remove and switch to ThreadingHTTPServer once python3.7 is
-# the minimum version supported.
-class ThreadedHTTPServer(socketserver.ThreadingMixIn, HTTPServer):
-    daemon_threads = True
-
-
 def main():
     global PRINT_REJECTED
     try:
@@ -806,20 +798,14 @@ def main():
         # it gracefully.
         try:
             with network_namespace.NetworkNamespace(consts.AMPHORA_NAMESPACE):
-                httpd = ThreadedHTTPServer(('127.0.0.1', 9102),
-                                           PrometheusProxy)
+                httpd = ThreadingHTTPServer(('127.0.0.1', 9102),
+                                            PrometheusProxy)
                 shutdownthread = threading.Thread(target=shutdown_thread,
                                                   args=(httpd,))
                 shutdownthread.start()
 
-                # TODO(johnsom) Uncomment this when we move to
-                #               ThreadingHTTPServer
-                # httpd.daemon_threads = True
+                httpd.daemon_threads = True
                 print("Now serving on port 9102")
                 httpd.serve_forever()
         except Exception:
             time.sleep(1)
-
-
-if __name__ == "__main__":
-    main()
