@@ -308,15 +308,19 @@ AMP_DATA = 'amp_data'
 AMP_VRRP_INT = 'amp_vrrp_int'
 AMPHORA = 'amphora'
 AMPHORA_DICT = 'amphora_dict'
+AMPHORA_FIREWALL_RULES = 'amphora_firewall_rules'
 AMPHORA_ID = 'amphora_id'
 AMPHORA_INDEX = 'amphora_index'
 AMPHORA_NETWORK_CONFIG = 'amphora_network_config'
 AMPHORAE = 'amphorae'
 AMPHORAE_NETWORK_CONFIG = 'amphorae_network_config'
+AMPHORAE_STATUS = 'amphorae_status'
 AMPS_DATA = 'amps_data'
 ANTI_AFFINITY = 'anti-affinity'
 ATTEMPT_NUMBER = 'attempt_number'
 BASE_PORT = 'base_port'
+BINDING_VNIC_TYPE = 'binding_vnic_type'
+BUILD_AMP_DATA = 'build_amp_data'
 BYTES_IN = 'bytes_in'
 BYTES_OUT = 'bytes_out'
 CACHED_ZONE = 'cached_zone'
@@ -363,6 +367,7 @@ ID = 'id'
 IMAGE_ID = 'image_id'
 IP_ADDRESS = 'ip_address'
 IPV6_ICMP = 'ipv6-icmp'
+IS_SRIOV = 'is_sriov'
 LB_NETWORK_IP = 'lb_network_ip'
 L7POLICY = 'l7policy'
 L7POLICY_ID = 'l7policy_id'
@@ -387,6 +392,8 @@ MESSAGE = 'message'
 NAME = 'name'
 NETWORK = 'network'
 NETWORK_ID = 'network_id'
+NEW_AMPHORAE = 'new_amphorae'
+NEW_AMPHORA_ID = 'new_amphora_id'
 NEXTHOP = 'nexthop'
 NICS = 'nics'
 OBJECT = 'object'
@@ -404,6 +411,7 @@ POOL_CHILD_COUNT = 'pool_child_count'
 POOL_ID = 'pool_id'
 POOL_UPDATES = 'pool_updates'
 PORT = 'port'
+PORT_DATA = 'port_data'
 PORT_ID = 'port_id'
 PORTS = 'ports'
 PROJECT_ID = 'project_id'
@@ -435,6 +443,7 @@ TLS_CERTIFICATE_ID = 'tls_certificate_id'
 TLS_CONTAINER_ID = 'tls_container_id'
 TOPOLOGY = 'topology'
 TOTAL_CONNECTIONS = 'total_connections'
+UNREACHABLE = 'unreachable'
 UPDATED_AT = 'updated_at'
 UPDATE_DICT = 'update_dict'
 UPDATED_PORTS = 'updated_ports'
@@ -448,6 +457,11 @@ VIP_QOS_POLICY_ID = 'vip_qos_policy_id'
 VIP_SG_ID = 'vip_sg_id'
 VIP_SUBNET = 'vip_subnet'
 VIP_SUBNET_ID = 'vip_subnet_id'
+VIP_VNIC_TYPE = 'vip_vnic_type'
+VNIC_TYPE = 'vnic_type'
+VNIC_TYPE_DIRECT = 'direct'
+VNIC_TYPE_NORMAL = 'normal'
+VRRP = 'vrrp'
 VRRP_ID = 'vrrp_id'
 VRRP_IP = 'vrrp_ip'
 VRRP_GROUP = 'vrrp_group'
@@ -456,6 +470,7 @@ VRRP_PORT_ID = 'vrrp_port_id'
 VRRP_PRIORITY = 'vrrp_priority'
 
 # Taskflow flow and task names
+AMP_UPDATE_FW_SUBFLOW = 'amphora-update-firewall-subflow'
 CERT_ROTATE_AMPHORA_FLOW = 'octavia-cert-rotate-amphora-flow'
 CREATE_AMPHORA_FLOW = 'octavia-create-amphora-flow'
 CREATE_AMPHORA_RETRY_SUBFLOW = 'octavia-create-amphora-retry-subflow'
@@ -484,6 +499,7 @@ DELETE_L7RULE_FLOW = 'octavia-delete-l7policy-flow'
 FAILOVER_AMPHORA_FLOW = 'octavia-failover-amphora-flow'
 FAILOVER_LOADBALANCER_FLOW = 'octavia-failover-loadbalancer-flow'
 FINALIZE_AMPHORA_FLOW = 'octavia-finalize-amphora-flow'
+FIREWALL_RULES_SUBFLOW = 'firewall-rules-subflow'
 LOADBALANCER_NETWORKING_SUBFLOW = 'octavia-new-loadbalancer-net-subflow'
 UPDATE_HEALTH_MONITOR_FLOW = 'octavia-update-health-monitor-flow'
 UPDATE_LISTENER_FLOW = 'octavia-update-listener-flow'
@@ -561,7 +577,9 @@ DELETE_MEMBER_INDB = 'octavia-delete-member-indb'
 ADMIN_DOWN_PORT = 'admin-down-port'
 AMPHORA_POST_VIP_PLUG = 'amphora-post-vip-plug'
 AMPHORA_RELOAD_LISTENER = 'amphora-reload-listener'
+AMPHORA_TO_AMPHORAE_VRRP_IP = 'amphora-to-amphorae-vrrp-ip'
 AMPHORA_TO_ERROR_ON_REVERT = 'amphora-to-error-on-revert'
+AMPHORAE_GET_CONNECTIVITY_STATUS = 'amphorae-get-connectivity-status'
 AMPHORAE_POST_NETWORK_PLUG = 'amphorae-post-network-plug'
 ATTACH_PORT = 'attach-port'
 CALCULATE_AMPHORA_DELTA = 'calculate-amphora-delta'
@@ -569,8 +587,10 @@ CREATE_VIP_BASE_PORT = 'create-vip-base-port'
 DELETE_AMPHORA = 'delete-amphora'
 DELETE_PORT = 'delete-port'
 DISABLE_AMP_HEALTH_MONITORING = 'disable-amphora-health-monitoring'
+GET_AMPHORA_FIREWALL_RULES = 'get-amphora-firewall-rules'
 GET_AMPHORA_NETWORK_CONFIGS_BY_ID = 'get-amphora-network-configs-by-id'
 GET_AMPHORAE_FROM_LB = 'get-amphorae-from-lb'
+GET_SUBNET_FROM_VIP = 'get-subnet-from-vip'
 HANDLE_NETWORK_DELTA = 'handle-network-delta'
 MARK_AMPHORA_DELETED = 'mark-amphora-deleted'
 MARK_AMPHORA_PENDING_DELETE = 'mark-amphora-pending-delete'
@@ -580,6 +600,7 @@ RELOAD_LB_AFTER_AMP_ASSOC = 'reload-lb-after-amp-assoc'
 RELOAD_LB_AFTER_AMP_ASSOC_FULL_GRAPH = 'reload-lb-after-amp-assoc-full-graph'
 RELOAD_LB_AFTER_PLUG_VIP = 'reload-lb-after-plug-vip'
 RELOAD_LB_BEFOR_ALLOCATE_VIP = 'reload-lb-before-allocate-vip'
+SET_AMPHORA_FIREWALL_RULES = 'set-amphora-firewall-rules'
 UPDATE_AMP_FAILOVER_DETAILS = 'update-amp-failover-details'
 
 
@@ -896,6 +917,7 @@ VIP_SECURITY_GROUP_PREFIX = 'lb-'
 
 AMP_BASE_PORT_PREFIX = 'octavia-lb-vrrp-'
 OCTAVIA_OWNED = 'octavia_owned'
+OCTAVIA_OWNER = 'Octavia'
 
 # Sadly in the LBaaS v2 API, header insertions are on the listener objects
 # but they should be on the pool. Dealing with it until v3.
@@ -910,6 +932,8 @@ AMPHORA_SUPPORTED_ALPN_PROTOCOLS = [lib_consts.ALPN_PROTOCOL_HTTP_2,
                                     lib_consts.ALPN_PROTOCOL_HTTP_1_1,
                                     lib_consts.ALPN_PROTOCOL_HTTP_1_0]
 
+SRIOV_VIP = 'sriov_vip'
+
 # Amphora interface fields
 IF_TYPE = 'if_type'
 BACKEND = 'backend'
@@ -950,3 +974,13 @@ IFLA_IFNAME = 'IFLA_IFNAME'
 
 # Amphora network directory
 AMP_NET_DIR_TEMPLATE = '/etc/octavia/interfaces/'
+
+# Amphora nftables constants
+NFT_ADD = 'add'
+NFT_CMD = '/usr/sbin/nft'
+NFT_FAMILY = 'inet'
+NFT_VIP_RULES_FILE = '/var/lib/octavia/nftables-vip.rules'
+NFT_VIP_TABLE = 'amphora_vip'
+NFT_VIP_CHAIN = 'amphora_vip_chain'
+NFT_SRIOV_PRIORITY = '-310'
+PROTOCOL = 'protocol'
