@@ -28,6 +28,7 @@ from octavia.controller.worker.v2.tasks import database_tasks
 from octavia.controller.worker.v2.tasks import lifecycle_tasks
 from octavia.controller.worker.v2.tasks import network_tasks
 from octavia.controller.worker.v2.tasks import retry_tasks
+from octavia.controller.worker.v2.tasks import shim_tasks
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
@@ -227,7 +228,7 @@ class AmphoraFlows(object):
 
     def get_vrrp_subflow(self, prefix, timeout_dict=None,
                          create_vrrp_group=True,
-                         get_amphorae_status=True):
+                         get_amphorae_status=True, flavor_dict=None):
         sf_name = prefix + '-' + constants.GET_VRRP_SUBFLOW
         vrrp_subflow = linear_flow.Flow(sf_name)
 
@@ -259,7 +260,7 @@ class AmphoraFlows(object):
         # unordered subflow.
         update_amps_subflow = unordered_flow.Flow('VRRP-update-subflow')
 
-        # We have three tasks to run in order, per amphora
+        # We have tasks to run in order, per amphora
         amp_0_subflow = linear_flow.Flow('VRRP-amp-0-update-subflow')
 
         amp_0_subflow.add(amphora_driver_tasks.AmphoraIndexUpdateVRRPInterface(
@@ -279,6 +280,21 @@ class AmphoraFlows(object):
             inject={constants.AMPHORA_INDEX: 0,
                     constants.TIMEOUT_DICT: timeout_dict}))
 
+        if flavor_dict and flavor_dict.get(constants.SRIOV_VIP, False):
+            amp_0_subflow.add(database_tasks.GetAmphoraFirewallRules(
+                name=sf_name + '-0-' + constants.GET_AMPHORA_FIREWALL_RULES,
+                requires=(constants.AMPHORAE,
+                          constants.AMPHORAE_NETWORK_CONFIG),
+                provides=constants.AMPHORA_FIREWALL_RULES,
+                inject={constants.AMPHORA_INDEX: 0}))
+
+            amp_0_subflow.add(amphora_driver_tasks.SetAmphoraFirewallRules(
+                name=sf_name + '-0-' + constants.SET_AMPHORA_FIREWALL_RULES,
+                requires=(constants.AMPHORAE, constants.AMPHORAE_STATUS,
+                          constants.AMPHORA_FIREWALL_RULES),
+                inject={constants.AMPHORA_INDEX: 0,
+                        constants.TIMEOUT_DICT: timeout_dict}))
+
         amp_0_subflow.add(amphora_driver_tasks.AmphoraIndexVRRPStart(
             name=sf_name + '-0-' + constants.AMP_VRRP_START,
             requires=(constants.AMPHORAE, constants.AMPHORAE_STATUS),
@@ -304,6 +320,22 @@ class AmphoraFlows(object):
             rebind={constants.NEW_AMPHORA_ID: constants.AMPHORA_ID},
             inject={constants.AMPHORA_INDEX: 1,
                     constants.TIMEOUT_DICT: timeout_dict}))
+
+        if flavor_dict and flavor_dict.get(constants.SRIOV_VIP, False):
+            amp_1_subflow.add(database_tasks.GetAmphoraFirewallRules(
+                name=sf_name + '-1-' + constants.GET_AMPHORA_FIREWALL_RULES,
+                requires=(constants.AMPHORAE,
+                          constants.AMPHORAE_NETWORK_CONFIG),
+                provides=constants.AMPHORA_FIREWALL_RULES,
+                inject={constants.AMPHORA_INDEX: 1}))
+
+            amp_1_subflow.add(amphora_driver_tasks.SetAmphoraFirewallRules(
+                name=sf_name + '-1-' + constants.SET_AMPHORA_FIREWALL_RULES,
+                requires=(constants.AMPHORAE, constants.AMPHORAE_STATUS,
+                          constants.AMPHORA_FIREWALL_RULES),
+                inject={constants.AMPHORA_INDEX: 1,
+                        constants.TIMEOUT_DICT: timeout_dict}))
+
         amp_1_subflow.add(amphora_driver_tasks.AmphoraIndexVRRPStart(
             name=sf_name + '-1-' + constants.AMP_VRRP_START,
             requires=(constants.AMPHORAE, constants.AMPHORAE_STATUS),
@@ -371,7 +403,8 @@ class AmphoraFlows(object):
 
     def get_amphora_for_lb_failover_subflow(
             self, prefix, role=constants.ROLE_STANDALONE,
-            failed_amp_vrrp_port_id=None, is_vrrp_ipv6=False):
+            failed_amp_vrrp_port_id=None, is_vrrp_ipv6=False,
+            flavor_dict=None):
         """Creates a new amphora that will be used in a failover flow.
 
         :requires: loadbalancer_id, flavor, vip, vip_sg_id, loadbalancer
@@ -392,13 +425,24 @@ class AmphoraFlows(object):
             prefix=prefix + '-' + constants.FAILOVER_LOADBALANCER_FLOW,
             role=role))
 
-        # Create the VIP base (aka VRRP) port for the amphora.
-        amp_for_failover_flow.add(network_tasks.CreateVIPBasePort(
-            name=prefix + '-' + constants.CREATE_VIP_BASE_PORT,
-            requires=(constants.VIP, constants.VIP_SG_ID,
-                      constants.AMPHORA_ID,
-                      constants.ADDITIONAL_VIPS),
-            provides=constants.BASE_PORT))
+        if flavor_dict and flavor_dict.get(constants.SRIOV_VIP, False):
+            amp_for_failover_flow.add(network_tasks.GetSubnetFromVIP(
+                name=prefix + '-' + constants.GET_SUBNET_FROM_VIP,
+                requires=constants.LOADBALANCER,
+                provides=constants.SUBNET))
+            amp_for_failover_flow.add(network_tasks.CreateSRIOVBasePort(
+                name=prefix + '-' + constants.PLUG_VIP_AMPHORA,
+                requires=(constants.LOADBALANCER, constants.AMPHORA,
+                          constants.SUBNET),
+                provides=constants.BASE_PORT))
+        else:
+            # Create the VIP base (aka VRRP) port for the amphora.
+            amp_for_failover_flow.add(network_tasks.CreateVIPBasePort(
+                name=prefix + '-' + constants.CREATE_VIP_BASE_PORT,
+                requires=(constants.VIP, constants.VIP_SG_ID,
+                          constants.AMPHORA_ID,
+                          constants.ADDITIONAL_VIPS),
+                provides=constants.BASE_PORT))
 
         # Attach the VIP base (aka VRRP) port to the amphora.
         amp_for_failover_flow.add(compute_tasks.AttachPort(
@@ -431,6 +475,27 @@ class AmphoraFlows(object):
             requires=(constants.AMPHORA, constants.LOADBALANCER,
                       constants.AMPHORAE_NETWORK_CONFIG)))
 
+        if flavor_dict and flavor_dict.get(constants.SRIOV_VIP, False):
+            amp_for_failover_flow.add(
+                shim_tasks.AmphoraToAmphoraeWithVRRPIP(
+                    name=prefix + '-' + constants.AMPHORA_TO_AMPHORAE_VRRP_IP,
+                    requires=(constants.AMPHORA, constants.BASE_PORT),
+                    provides=constants.NEW_AMPHORAE))
+            amp_for_failover_flow.add(database_tasks.GetAmphoraFirewallRules(
+                name=prefix + '-' + constants.GET_AMPHORA_FIREWALL_RULES,
+                requires=(constants.AMPHORAE,
+                          constants.AMPHORAE_NETWORK_CONFIG),
+                rebind={constants.AMPHORAE: constants.NEW_AMPHORAE},
+                provides=constants.AMPHORA_FIREWALL_RULES,
+                inject={constants.AMPHORA_INDEX: 0}))
+            amp_for_failover_flow.add(
+                amphora_driver_tasks.SetAmphoraFirewallRules(
+                    name=prefix + '-' + constants.SET_AMPHORA_FIREWALL_RULES,
+                    requires=(constants.AMPHORAE,
+                              constants.AMPHORA_FIREWALL_RULES),
+                    rebind={constants.AMPHORAE: constants.NEW_AMPHORAE},
+                    inject={constants.AMPHORA_INDEX: 0}))
+
         # Plug member ports
         amp_for_failover_flow.add(network_tasks.CalculateAmphoraDelta(
             name=prefix + '-' + constants.CALCULATE_AMPHORA_DELTA,
@@ -449,7 +514,8 @@ class AmphoraFlows(object):
 
         return amp_for_failover_flow
 
-    def get_failover_amphora_flow(self, failed_amphora, lb_amp_count):
+    def get_failover_amphora_flow(self, failed_amphora, lb_amp_count,
+                                  flavor_dict=None):
         """Get a Taskflow flow to failover an amphora.
 
         1. Build a replacement amphora.
@@ -459,6 +525,7 @@ class AmphoraFlows(object):
 
         :param failed_amphora: The amphora dict to failover.
         :param lb_amp_count: The number of amphora on this load balancer.
+        :param flavor_dict: The load balancer flavor dictionary.
         :returns: The flow that will provide the failover.
         """
         failover_amp_flow = linear_flow.Flow(
@@ -519,7 +586,7 @@ class AmphoraFlows(object):
                 role=failed_amphora[constants.ROLE],
                 failed_amp_vrrp_port_id=failed_amphora.get(
                     constants.VRRP_PORT_ID),
-                is_vrrp_ipv6=is_vrrp_ipv6))
+                is_vrrp_ipv6=is_vrrp_ipv6, flavor_dict=flavor_dict))
 
         failover_amp_flow.add(
             self.get_delete_amphora_flow(
@@ -587,7 +654,8 @@ class AmphoraFlows(object):
             failover_amp_flow.add(
                 self.get_vrrp_subflow(constants.GET_VRRP_SUBFLOW,
                                       timeout_dict, create_vrrp_group=False,
-                                      get_amphorae_status=False))
+                                      get_amphorae_status=False,
+                                      flavor_dict=flavor_dict))
 
         # Reload the listener. This needs to be done here because
         # it will create the required haproxy check scripts for
