@@ -16,8 +16,8 @@ from oslo_db.sqlalchemy import models
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 import sqlalchemy as sa
-from sqlalchemy.ext import declarative
 from sqlalchemy.orm import collections
+from sqlalchemy.orm import declarative_base
 
 
 class OctaviaBase(models.ModelBase):
@@ -51,6 +51,9 @@ class OctaviaBase(models.ModelBase):
             return obj.__class__.__name__ + obj.project_id
         if obj.__class__.__name__ in ['AvailabilityZone']:
             return obj.__class__.__name__ + obj.name
+        if obj.__class__.__name__ in ['AdditionalVip']:
+            return (obj.__class__.__name__ +
+                    obj.load_balancer_id + obj.subnet_id)
         raise NotImplementedError
 
     def to_data_model(self, _graph_nodes=None):
@@ -186,7 +189,7 @@ class TagMixin(object):
         self._tags = new_tags
 
 
-BASE = declarative.declarative_base(cls=OctaviaBase)
+BASE = declarative_base(cls=OctaviaBase)
 
 
 class Tags(BASE):
