@@ -14,6 +14,7 @@
 
 import abc
 
+from octavia.common import constants
 from octavia.common import exceptions
 
 
@@ -108,7 +109,8 @@ class AbstractNetworkDriver(object, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def create_port(self, network_id, name=None, fixed_ips=(),
                     secondary_ips=(), security_group_ids=(),
-                    admin_state_up=True, qos_policy_id=None):
+                    admin_state_up=True, qos_policy_id=None,
+                    vnic_type=constants.VNIC_TYPE_NORMAL):
         """Creates a network port.
 
         fixed_ips = [{'subnet_id': <id>, ('ip_address': <IP>')},]
@@ -141,21 +143,6 @@ class AbstractNetworkDriver(object, metaclass=abc.ABCMeta):
         :returns: None
         """
 
-    @abc.abstractmethod
-    def plug_vip(self, load_balancer, vip):
-        """Plugs a virtual ip as the frontend connection of a load balancer.
-
-        Sets up the routing of traffic from the vip to the load balancer
-        and its amphorae.
-
-        :param load_balancer: octavia.common.data_models.LoadBalancer instance
-        :param vip: octavia.common.data_models.VIP instance
-        :return: dict consisting of amphora_id as key and bind_ip as value.
-                 bind_ip is the ip that the amphora should listen on to
-                 receive traffic to load balance.
-        :raises: PlugVIPException, PortNotFound
-        """
-
     @abc.abstractmethod
     def unplug_vip(self, load_balancer, vip):
         """Unplugs a virtual ip as the frontend connection of a load balancer.
