@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from octavia.common import constants
 from octavia.common import data_models
 
 
@@ -81,7 +82,8 @@ class Port(data_models.BaseDataModel):
     def __init__(self, id=None, name=None, device_id=None, device_owner=None,
                  mac_address=None, network_id=None, status=None,
                  project_id=None, admin_state_up=None, fixed_ips=None,
-                 network=None, qos_policy_id=None, security_group_ids=None):
+                 network=None, qos_policy_id=None, security_group_ids=None,
+                 vnic_type=constants.VNIC_TYPE_NORMAL):
         self.id = id
         self.name = name
         self.device_id = device_id
@@ -95,6 +97,7 @@ class Port(data_models.BaseDataModel):
         self.network = network
         self.qos_policy_id = qos_policy_id
         self.security_group_ids = security_group_ids or []
+        self.vnic_type = vnic_type
 
     def get_subnet_id(self, fixed_ip_address):
         for fixed_ip in self.fixed_ips:
@@ -135,7 +138,7 @@ class AmphoraNetworkConfig(data_models.BaseDataModel):
 
     def __init__(self, amphora=None, vip_subnet=None, vip_port=None,
                  vrrp_subnet=None, vrrp_port=None, ha_subnet=None,
-                 ha_port=None):
+                 ha_port=None, additional_vip_data=None):
         self.amphora = amphora
         self.vip_subnet = vip_subnet
         self.vip_port = vip_port
@@ -143,6 +146,14 @@ class AmphoraNetworkConfig(data_models.BaseDataModel):
         self.vrrp_port = vrrp_port
         self.ha_subnet = ha_subnet
         self.ha_port = ha_port
+        self.additional_vip_data = additional_vip_data or []
+
+
+class AdditionalVipData(data_models.BaseDataModel):
+
+    def __init__(self, ip_address=None, subnet=None):
+        self.ip_address = ip_address
+        self.subnet = subnet
 
 
 class HostRoute(data_models.BaseDataModel):
