@@ -34,7 +34,6 @@ from octavia.network.drivers.neutron import utils
 LOG = logging.getLogger(__name__)
 AAP_EXT_ALIAS = 'allowed-address-pairs'
 PROJECT_ID_ALIAS = 'project-id'
-OCTAVIA_OWNER = 'Octavia'
 
 CONF = cfg.CONF
 
@@ -89,7 +88,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
                 constants.NETWORK_ID: subnet.network_id,
                 constants.FIXED_IPS: [{'subnet_id': subnet.id}],
                 constants.ADMIN_STATE_UP: True,
-                constants.DEVICE_OWNER: OCTAVIA_OWNER,
+                constants.DEVICE_OWNER: constants.OCTAVIA_OWNER,
             }
             new_port = self.network_proxy.create_port(**port)
             new_port = utils.convert_port_to_model(new_port)
@@ -364,12 +363,13 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         """
         try:
             for amphora in vip.load_balancer.amphorae:
-                try:
-                    self.network_proxy.delete_port(amphora.vrrp_port_id)
-                except os_exceptions.ResourceNotFound:
-                    LOG.debug(
-                        'VIP instance port %s already deleted. Skipping.',
-                        amphora.vrrp_port_id)
+                if amphora.vrrp_port_id:
+                    try:
+                        self.network_proxy.delete_port(amphora.vrrp_port_id)
+                    except os_exceptions.ResourceNotFound:
+                        LOG.debug(
+                            'VIP instance port %s already deleted. Skipping.',
+                            amphora.vrrp_port_id)
         except AttributeError as ex:
             LOG.warning(f"Cannot delete port from amphorae. Object does not "
                         f"exist ({ex!r})")
@@ -384,7 +384,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
 
         self._delete_security_group(vip, port)
 
-        if port and port.device_owner == OCTAVIA_OWNER:
+        if port and port.device_owner == constants.OCTAVIA_OWNER:
             try:
                 self.network_proxy.delete_port(vip.port_id)
             except os_exceptions.ResourceNotFound:
@@ -442,18 +442,6 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
             vrrp_port_id=interface.port_id,
             ha_port_id=vip.port_id)
 
-    # todo (xgerman): Delete later
-    def plug_vip(self, load_balancer, vip):
-        self.update_vip_sg(load_balancer, vip)
-        plugged_amphorae = []
-        subnet = self.get_subnet(vip.subnet_id)
-        for amphora in filter(
-            lambda amp: amp.status == constants.AMPHORA_ALLOCATED,
-                load_balancer.amphorae):
-            plugged_amphorae.append(self.plug_aap_port(load_balancer, vip,
-                                                       amphora, subnet))
-        return plugged_amphorae
-
     def _validate_fixed_ip(self, fixed_ips, subnet_id, ip_address):
         """Validate an IP address exists in a fixed_ips dict
 
@@ -479,6 +467,16 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         return list_of_dicts
 
     def allocate_vip(self, load_balancer):
+        """Allocates a virtual ip.
+
+        Reserves the IP for later use as the frontend connection of a load
+        balancer.
+
+        :param load_balancer: octavia.common.data_models.LoadBalancer instance
+        :return: octavia.common.data_models.Vip,
+                 list(octavia.common.data_models.AdditionalVip)
+        :raises: AllocateVIPException, PortNotFound, SubnetNotFound
+        """
         if load_balancer.vip.port_id:
             try:
                 port = self.get_port(load_balancer.vip.port_id)
@@ -490,7 +488,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
                     LOG.info('Port %s already exists. Nothing to be done.',
                              load_balancer.vip.port_id)
                     return self._port_to_vip(port, load_balancer)
-                LOG.error('Neutron VIP mis-match. Expected ip %s on '
+                LOG.error('Neutron VIP mismatch. Expected ip %s on '
                           'subnet %s in network %s. Neutron has fixed_ips %s '
                           'in network %s. Deleting and recreating the VIP '
                           'port.', load_balancer.vip.ip_address,
@@ -523,7 +521,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
 
         fixed_ip = {}
         if load_balancer.vip.subnet_id:
-            fixed_ip['subnet_id'] = load_balancer.vip.subnet_id
+            fixed_ip[constants.SUBNET_ID] = load_balancer.vip.subnet_id
         if load_balancer.vip.ip_address:
             fixed_ip[constants.IP_ADDRESS] = load_balancer.vip.ip_address
 
@@ -555,7 +553,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
             constants.NETWORK_ID: load_balancer.vip.network_id,
             constants.ADMIN_STATE_UP: False,
             'device_id': 'lb-{0}'.format(load_balancer.id),
-            constants.DEVICE_OWNER: OCTAVIA_OWNER,
+            constants.DEVICE_OWNER: constants.OCTAVIA_OWNER,
             project_id_key: load_balancer.project_id}
 
         if fixed_ips:
@@ -828,7 +826,8 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
 
     def create_port(self, network_id, name=None, fixed_ips=(),
                     secondary_ips=(), security_group_ids=(),
-                    admin_state_up=True, qos_policy_id=None):
+                    admin_state_up=True, qos_policy_id=None,
+                    vnic_type=constants.VNIC_TYPE_NORMAL):
         """Creates a network port.
 
         fixed_ips = [{'subnet_id': <id>, ('ip_addrss': <IP>')},]
@@ -840,6 +839,7 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         :param secondary_ips: A list of secondary IPs to add to the port.
         :param security_group_ids: A list of security group IDs for the port.
         :param qos_policy_id: The QoS policy ID to apply to the port.
+        :param vnic_type: The vNIC type this port should attach to.
         :returns port: A port data model object.
         """
         try:
@@ -848,7 +848,8 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
                 aap_list.append({constants.IP_ADDRESS: ip})
             port = {constants.NETWORK_ID: network_id,
                     constants.ADMIN_STATE_UP: admin_state_up,
-                    constants.DEVICE_OWNER: OCTAVIA_OWNER}
+                    constants.DEVICE_OWNER: constants.OCTAVIA_OWNER,
+                    constants.BINDING_VNIC_TYPE: vnic_type}
             if aap_list:
                 port[constants.ALLOWED_ADDRESS_PAIRS] = aap_list
             if fixed_ips:
