@@ -14,6 +14,7 @@
 
 from unittest import mock
 
+from octavia_lib.common import constants as lib_consts
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_utils import uuidutils
@@ -33,7 +34,7 @@ class TestL7Policy(base.BaseAPITest):
     root_tag_links = 'l7policies_links'
 
     def setUp(self):
-        super(TestL7Policy, self).setUp()
+        super().setUp()
         self.lb = self.create_load_balancer(uuidutils.generate_uuid())
         self.lb_id = self.lb.get('loadbalancer').get('id')
         self.project_id = self.lb.get('loadbalancer').get('project_id')
@@ -66,7 +67,8 @@ class TestL7Policy(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -98,7 +100,8 @@ class TestL7Policy(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             response = self.get(self.L7POLICY_PATH.format(
                 l7policy_id=api_l7policy.get('id')), status=403)
@@ -197,7 +200,8 @@ class TestL7Policy(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings',
                          auth_strategy=constants.KEYSTONE)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                api_l7p_c.get('project_id')):
             override_credentials = {
                 'service_user_id': None,
@@ -254,7 +258,8 @@ class TestL7Policy(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings',
                          auth_strategy=constants.KEYSTONE)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                None):
             override_credentials = {
                 'service_user_id': None,
@@ -306,7 +311,8 @@ class TestL7Policy(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings',
                          auth_strategy=constants.KEYSTONE)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                api_l7p_c.get('project_id')):
             override_credentials = {
                 'service_user_id': None,
@@ -345,7 +351,8 @@ class TestL7Policy(base.BaseAPITest):
 
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             policies = self.get(self.L7POLICIES_PATH, status=403).json
 
@@ -494,7 +501,7 @@ class TestL7Policy(base.BaseAPITest):
         links = middle[self.root_tag_links]
         self.assertEqual(1, len(objs))
         self.assertEqual(2, len(links))
-        self.assertItemsEqual(['previous', 'next'],
+        self.assertCountEqual(['previous', 'next'],
                               [link['rel'] for link in links])
 
     def test_get_all_fields_filter(self):
@@ -669,7 +676,8 @@ class TestL7Policy(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
 
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -711,7 +719,8 @@ class TestL7Policy(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
 
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             api_l7policy = self.create_l7policy(
                 self.listener_id,
@@ -858,6 +867,14 @@ class TestL7Policy(base.BaseAPITest):
                     'redirect_url': 'http://a.com'}
         self.post(self.L7POLICIES_PATH, self._build_body(l7policy), status=403)
 
+    def test_negative_create_prometheus_listener(self):
+        prometheus_listener = self.create_listener(
+            lib_consts.PROTOCOL_PROMETHEUS, 8123, lb_id=self.lb_id)
+        prometheus_listener_id = prometheus_listener.get('listener').get('id')
+        self.set_lb_status(self.lb_id)
+        l7policy = {'listener_id': prometheus_listener_id, 'name': 'test1'}
+        self.post(self.L7POLICIES_PATH, self._build_body(l7policy), status=400)
+
     def test_update(self):
         api_l7policy = self.create_l7policy(self.listener_id,
                                             constants.L7POLICY_ACTION_REJECT,
@@ -893,7 +910,8 @@ class TestL7Policy(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -937,7 +955,8 @@ class TestL7Policy(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             response = self.put(self.L7POLICY_PATH.format(
                 l7policy_id=api_l7policy.get('id')),
@@ -1137,7 +1156,8 @@ class TestL7Policy(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -1185,7 +1205,8 @@ class TestL7Policy(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             self.delete(self.L7POLICY_PATH.format(
                 l7policy_id=api_l7policy.get('id')), status=403)
@@ -1355,21 +1376,27 @@ class TestL7Policy(base.BaseAPITest):
             self.set_object_status(self.lb_repo, self.lb_id)
             port = port + 1
             for pool_proto in invalid_map[listener_proto]:
-                pool = self.create_pool(
-                    self.lb_id, pool_proto,
-                    constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
-                self.set_object_status(self.lb_repo, self.lb_id)
+                if pool_proto == constants.PROTOCOL_TERMINATED_HTTPS:
+                    pool = self.create_pool(
+                        self.lb_id, pool_proto,
+                        constants.LB_ALGORITHM_ROUND_ROBIN, status=400)
+                    self.assertIn("Invalid input", pool['faultstring'])
+                else:
+                    pool = self.create_pool(
+                        self.lb_id, pool_proto,
+                        constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+                    self.set_object_status(self.lb_repo, self.lb_id)
 
-                l7policy['listener_id'] = listener.get('id')
-                l7policy['redirect_pool_id'] = pool.get('id')
-                expect_error_msg = ("Validation failure: The pool protocol "
-                                    "'%s' is invalid while the listener "
-                                    "protocol is '%s'.") % (pool_proto,
-                                                            listener_proto)
-                res = self.post(self.L7POLICIES_PATH,
-                                self._build_body(l7policy), status=400)
-                self.assertEqual(expect_error_msg, res.json['faultstring'])
-                self.assert_correct_status(lb_id=self.lb_id)
+                    l7policy['listener_id'] = listener.get('id')
+                    l7policy['redirect_pool_id'] = pool.get('id')
+                    expect_error_msg = (
+                        "Validation failure: The pool protocol '%s' is "
+                        "invalid while the listener protocol is '%s'.") % (
+                        pool_proto, listener_proto)
+                    res = self.post(self.L7POLICIES_PATH,
+                                    self._build_body(l7policy), status=400)
+                    self.assertEqual(expect_error_msg, res.json['faultstring'])
+                    self.assert_correct_status(lb_id=self.lb_id)
 
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
     def test_listener_pool_protocol_map_put(self, mock_cert_data):
@@ -1413,21 +1440,27 @@ class TestL7Policy(base.BaseAPITest):
             self.set_object_status(self.lb_repo, self.lb_id)
             port = port + 1
             for pool_proto in invalid_map[listener_proto]:
-                pool = self.create_pool(
-                    self.lb_id, pool_proto,
-                    constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
-                self.set_object_status(self.lb_repo, self.lb_id)
-                l7policy = self.create_l7policy(
-                    listener.get('id'),
-                    constants.L7POLICY_ACTION_REJECT).get(self.root_tag)
-                self.set_object_status(self.lb_repo, self.lb_id)
-                new_l7policy['redirect_pool_id'] = pool.get('id')
-                expect_error_msg = ("Validation failure: The pool protocol "
-                                    "'%s' is invalid while the listener "
-                                    "protocol is '%s'.") % (pool_proto,
-                                                            listener_proto)
-                res = self.put(self.L7POLICY_PATH.format(
-                    l7policy_id=l7policy.get('id')),
-                    self._build_body(new_l7policy), status=400)
-                self.assertEqual(expect_error_msg, res.json['faultstring'])
-                self.assert_correct_status(lb_id=self.lb_id)
+                if pool_proto == constants.PROTOCOL_TERMINATED_HTTPS:
+                    pool = self.create_pool(
+                        self.lb_id, pool_proto,
+                        constants.LB_ALGORITHM_ROUND_ROBIN, status=400)
+                    self.assertIn("Invalid input", pool['faultstring'])
+                else:
+                    pool = self.create_pool(
+                        self.lb_id, pool_proto,
+                        constants.LB_ALGORITHM_ROUND_ROBIN).get('pool')
+                    self.set_object_status(self.lb_repo, self.lb_id)
+                    l7policy = self.create_l7policy(
+                        listener.get('id'),
+                        constants.L7POLICY_ACTION_REJECT).get(self.root_tag)
+                    self.set_object_status(self.lb_repo, self.lb_id)
+                    new_l7policy['redirect_pool_id'] = pool.get('id')
+                    expect_error_msg = (
+                        "Validation failure: The pool protocol '%s' is "
+                        "invalid while the listener protocol is '%s'.") % (
+                        pool_proto, listener_proto)
+                    res = self.put(self.L7POLICY_PATH.format(
+                        l7policy_id=l7policy.get('id')),
+                        self._build_body(new_l7policy), status=400)
+                    self.assertEqual(expect_error_msg, res.json['faultstring'])
+                    self.assert_correct_status(lb_id=self.lb_id)
