@@ -15,6 +15,7 @@
 import errno
 import os
 import socket
+import subprocess
 from unittest import mock
 
 import pyroute2
@@ -74,6 +75,7 @@ class TestInterface(base.TestCase):
                    '],\n'
                    '"mtu": 1450,\n'
                    '"name": "eth1",\n'
+                   '"if_type": "mytype",\n'
                    '"routes": [\n'
                    '{"dst": "0.0.0.0/0",\n'
                    '"gateway": "10.0.0.1"},\n'
@@ -107,6 +109,7 @@ class TestInterface(base.TestCase):
 
         expected_dict = {
             consts.NAME: "eth1",
+            consts.IF_TYPE: "mytype",
             consts.MTU: 1450,
             consts.ADDRESSES: [{
                 consts.ADDRESS: "10.0.0.2",
@@ -324,12 +327,14 @@ class TestInterface(base.TestCase):
     @mock.patch('pyroute2.IPRoute.route')
     @mock.patch('pyroute2.IPRoute.addr')
     @mock.patch('pyroute2.IPRoute.link')
+    @mock.patch('pyroute2.IPRoute.get_links')
     @mock.patch('pyroute2.IPRoute.link_lookup')
     @mock.patch('subprocess.check_output')
-    def test_up(self, mock_check_output, mock_link_lookup, mock_link,
-                mock_addr, mock_route, mock_rule):
+    def test_up(self, mock_check_output, mock_link_lookup, mock_get_links,
+                mock_link, mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -376,6 +381,10 @@ class TestInterface(base.TestCase):
         idx = mock.MagicMock()
         mock_link_lookup.return_value = [idx]
 
+        mock_get_links.return_value = [{
+            consts.STATE: consts.IFACE_DOWN
+        }]
+
         controller = interface.InterfaceController()
         controller.up(iface)
 
@@ -440,19 +449,439 @@ class TestInterface(base.TestCase):
             mock.call(["post-up", "eth1"])
         ])
 
+    @mock.patch('octavia.amphorae.backends.utils.network_namespace.'
+                'NetworkNamespace')
+    @mock.patch('octavia.amphorae.backends.utils.nftable_utils.'
+                'write_nftable_vip_rules_file')
     @mock.patch('pyroute2.IPRoute.rule')
     @mock.patch('pyroute2.IPRoute.route')
     @mock.patch('pyroute2.IPRoute.addr')
     @mock.patch('pyroute2.IPRoute.link')
+    @mock.patch('pyroute2.IPRoute.get_links')
+    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('subprocess.check_output')
+    def test_up_sriov(self, mock_check_output, mock_link_lookup,
+                      mock_get_links, mock_link, mock_addr, mock_route,
+                      mock_rule, mock_nftable, mock_netns):
+        iface = interface_file.InterfaceFile(
+            name="fake-eth1",
+            if_type="vip",
+            mtu=1450,
+            addresses=[{
+                consts.ADDRESS: '192.0.2.4',
+                consts.PREFIXLEN: 24
+            }, {
+                consts.ADDRESS: '198.51.100.4',
+                consts.PREFIXLEN: 16
+            }, {
+                consts.ADDRESS: '2001:db8::3',
+                consts.PREFIXLEN: 64
+            }],
+            routes=[{
+                consts.DST: '203.0.113.0/24',
+                consts.GATEWAY: '192.0.2.1',
+                consts.TABLE: 10,
+                consts.ONLINK: True
+            }, {
+                consts.DST: '198.51.100.0/24',
+                consts.GATEWAY: '192.0.2.2',
+                consts.PREFSRC: '192.0.2.4',
+                consts.SCOPE: 'link'
+            }, {
+                consts.DST: '2001:db8:2::1/128',
+                consts.GATEWAY: '2001:db8::1'
+            }],
+            rules=[{
+                consts.SRC: '203.0.113.1',
+                consts.SRC_LEN: 32,
+                consts.TABLE: 20,
+            }, {
+                consts.SRC: '2001:db8::1',
+                consts.SRC_LEN: 128,
+                consts.TABLE: 40,
+            }],
+            scripts={
+                consts.IFACE_UP: [{
+                    consts.COMMAND: "post-up fake-eth1"
+                }],
+                consts.IFACE_DOWN: [{
+                    consts.COMMAND: "post-down fake-eth1"
+                }],
+            },
+            is_sriov=True)
+
+        idx = mock.MagicMock()
+        mock_link_lookup.return_value = [idx]
+
+        mock_get_links.return_value = [{
+            consts.STATE: consts.IFACE_DOWN
+        }]
+
+        controller = interface.InterfaceController()
+        controller.up(iface)
+
+        mock_link.assert_called_once_with(
+            controller.SET,
+            index=idx,
+            state=consts.IFACE_UP,
+            mtu=1450)
+
+        mock_addr.assert_has_calls([
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='192.0.2.4',
+                      prefixlen=24,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='198.51.100.4',
+                      prefixlen=16,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='2001:db8::3',
+                      prefixlen=64,
+                      family=socket.AF_INET6)
+        ])
+
+        mock_route.assert_has_calls([
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='203.0.113.0/24',
+                      gateway='192.0.2.1',
+                      table=10,
+                      onlink=True,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='198.51.100.0/24',
+                      gateway='192.0.2.2',
+                      prefsrc='192.0.2.4',
+                      scope='link',
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='2001:db8:2::1/128',
+                      gateway='2001:db8::1',
+                      family=socket.AF_INET6)])
+
+        mock_rule.assert_has_calls([
+            mock.call(controller.ADD,
+                      src="203.0.113.1",
+                      src_len=32,
+                      table=20,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      src="2001:db8::1",
+                      src_len=128,
+                      table=40,
+                      family=socket.AF_INET6)])
+
+        mock_check_output.assert_has_calls([
+            mock.call([consts.NFT_CMD, consts.NFT_ADD, 'table',
+                       consts.NFT_FAMILY, consts.NFT_VIP_TABLE], stderr=-2),
+            mock.call([consts.NFT_CMD, consts.NFT_ADD, 'chain',
+                       consts.NFT_FAMILY, consts.NFT_VIP_TABLE,
+                       consts.NFT_VIP_CHAIN, '{', 'type', 'filter', 'hook',
+                       'ingress', 'device', 'fake-eth1', 'priority',
+                       consts.NFT_SRIOV_PRIORITY, ';', 'policy', 'drop', ';',
+                       '}'], stderr=-2),
+            mock.call([consts.NFT_CMD, '-o', '-f', consts.NFT_VIP_RULES_FILE],
+                      stderr=-2),
+            mock.call(["post-up", "fake-eth1"])
+        ])
+
+        mock_nftable.assert_called_once_with('fake-eth1', [])
+
+    @mock.patch('pyroute2.IPRoute.rule')
+    @mock.patch('pyroute2.IPRoute.route')
+    @mock.patch('pyroute2.IPRoute.addr')
+    @mock.patch('pyroute2.IPRoute.link')
+    @mock.patch('pyroute2.IPRoute.get_links')
+    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('pyroute2.IPRoute.get_rules')
+    @mock.patch('subprocess.check_output')
+    def test_up_backend(self, mock_check_output, mock_get_rules,
+                        mock_link_lookup, mock_get_links, mock_link, mock_addr,
+                        mock_route, mock_rule):
+        iface = interface_file.InterfaceFile(
+            name="eth1",
+            if_type="backend",
+            mtu=1450,
+            addresses=[{
+                consts.ADDRESS: '1.2.3.4',
+                consts.PREFIXLEN: 24
+            }],
+            routes=[],
+            rules=[],
+            scripts={
+                consts.IFACE_UP: [{
+                    consts.COMMAND: "post-up eth1"
+                }],
+                consts.IFACE_DOWN: [{
+                    consts.COMMAND: "post-down eth1"
+                }],
+            })
+
+        idx = mock.MagicMock()
+        mock_link_lookup.return_value = [idx]
+
+        mock_get_links.return_value = [{
+            consts.STATE: consts.IFACE_DOWN
+        }]
+        mock_get_rules.return_value = [{
+            'src_len': 32,
+            'attrs': {
+                'FRA_SRC': '1.1.1.1',
+                'FRA_TABLE': 20,
+                'FRA_PROTOCOL': 0
+            }
+        }]
+
+        controller = interface.InterfaceController()
+        controller.up(iface)
+
+        mock_link.assert_called_once_with(
+            controller.SET,
+            index=idx,
+            state=consts.IFACE_UP,
+            mtu=1450)
+
+        mock_addr.assert_has_calls([
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='1.2.3.4',
+                      prefixlen=24,
+                      family=socket.AF_INET),
+        ])
+
+        mock_route.assert_called_once_with(
+            'dump', family=mock.ANY, match=mock.ANY)
+
+        # for 'backend' iface, we don't update the rules
+        mock_rule.assert_not_called()
+
+        mock_check_output.assert_has_calls([
+            mock.call(["post-up", "eth1"])
+        ])
+
+    @mock.patch('pyroute2.IPRoute.rule')
+    @mock.patch('pyroute2.IPRoute.route')
+    @mock.patch('pyroute2.IPRoute.addr')
+    @mock.patch('pyroute2.IPRoute.link')
+    @mock.patch('pyroute2.IPRoute.get_links')
+    @mock.patch('pyroute2.IPRoute.get_rules')
+    @mock.patch('pyroute2.IPRoute.get_routes')
+    @mock.patch('pyroute2.IPRoute.get_addr')
+    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('subprocess.check_output')
+    @mock.patch('octavia.amphorae.backends.utils.interface.'
+                'InterfaceController._wait_tentative')
+    def test_up_update(self, mock_wait_tentative, mock_check_output,
+                       mock_link_lookup, mock_get_addr, mock_get_routes,
+                       mock_get_rules, mock_get_links, mock_link, mock_addr,
+                       mock_route, mock_rule):
+        iface = interface_file.InterfaceFile(
+            name="eth1",
+            if_type="vip",
+            mtu=1450,
+            addresses=[{
+                consts.ADDRESS: '1.2.3.4',
+                consts.PREFIXLEN: 24
+            }, {
+                consts.ADDRESS: '10.2.3.4',
+                consts.PREFIXLEN: 16
+            }, {
+                consts.ADDRESS: '10.4.3.2',
+                consts.PREFIXLEN: 16,
+                consts.OCTAVIA_OWNED: False
+            }, {
+                consts.ADDRESS: '2001:db8::3',
+                consts.PREFIXLEN: 64
+            }],
+            routes=[{
+                consts.DST: '10.0.0.0/8',
+                consts.GATEWAY: '1.0.0.1',
+                consts.TABLE: 10,
+                consts.ONLINK: True
+            }, {
+                consts.DST: '20.0.0.0/8',
+                consts.GATEWAY: '1.0.0.2',
+                consts.PREFSRC: '1.2.3.4',
+                consts.SCOPE: 'link'
+            }, {
+                consts.DST: '2001:db8:2::1/128',
+                consts.GATEWAY: '2001:db8::1'
+            }],
+            rules=[{
+                consts.SRC: '1.1.1.1',
+                consts.SRC_LEN: 32,
+                consts.TABLE: 20,
+            }, {
+                consts.SRC: '2001:db8::1',
+                consts.SRC_LEN: 128,
+                consts.TABLE: 40,
+            }],
+            scripts={
+                consts.IFACE_UP: [{
+                    consts.COMMAND: "post-up eth1"
+                }],
+                consts.IFACE_DOWN: [{
+                    consts.COMMAND: "post-down eth1"
+                }],
+            })
+
+        idx = mock.MagicMock()
+        mock_link_lookup.return_value = [idx]
+
+        mock_get_links.return_value = [{
+            consts.STATE: consts.IFACE_UP
+        }]
+
+        mock_get_addr.return_value = [{
+            'prefixlen': 24,
+            'attrs': {
+                'IFA_ADDRESS': '2.0.0.1',
+                'IFA_FLAGS': 0x80  # IFA_F_PERMANENT
+            }
+        }, {
+            'prefixlen': 16,
+            'attrs': {
+                'IFA_ADDRESS': '10.2.3.4',
+                'IFA_FLAGS': 0x80  # IFA_F_PERMANENT
+            }
+        }, {
+            'prefixlen': 16,
+            'attrs': {
+                'IFA_ADDRESS': '10.2.3.5',
+                'IFA_FLAGS': 0x0  # not IFA_F_PERMANENT
+            }
+        }]
+
+        mock_get_routes.return_value = [{
+            'dst_len': 16,
+            'family': 2,
+            'proto': 4,  # STATIC
+            'attrs': {
+                'RTA_DST': '24.24.0.0',
+                'RTA_GATEWAY': '2.0.0.254',
+                'RTA_PREFSRC': '2.0.0.1',
+                'RTA_TABLE': 254
+            }
+        }, {
+            'dst_len': 8,
+            'family': 2,
+            'proto': 4,  # STATIC
+            'attrs': {
+                'RTA_DST': '20.0.0.0',
+                'RTA_GATEWAY': '1.0.0.2',
+                'RTA_PREFSRC': '1.2.3.4',
+                'RTA_TABLE': 254
+            }
+        }]
+
+        mock_get_rules.return_value = [{
+            'src_len': 32,
+            'attrs': {
+                'FRA_SRC': '1.1.1.1',
+                'FRA_TABLE': 20,
+                'FRA_PROTOCOL': 0
+            }
+        }, {
+            'src_len': 32,
+            'attrs': {
+                'FRA_SRC': '2.2.2.2',
+                'FRA_TABLE': 254,
+                'FRA_PROTOCOL': 18  # Keepalived
+            }
+        }, {
+            'src_len': 32,
+            'attrs': {
+                'FRA_SRC': '3.3.3.3',
+                'FRA_TABLE': 254,
+                'FRA_PROTOCOL': 0
+            }
+        }]
+
+        controller = interface.InterfaceController()
+        controller.up(iface)
+
+        mock_link.assert_not_called()
+
+        mock_addr.assert_has_calls([
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='1.2.3.4',
+                      prefixlen=24,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='2001:db8::3',
+                      prefixlen=64,
+                      family=socket.AF_INET6),
+            mock.call(controller.DELETE,
+                      index=idx,
+                      address='2.0.0.1',
+                      prefixlen=24,
+                      family=socket.AF_INET)
+        ])
+
+        mock_route.assert_has_calls([
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='10.0.0.0/8',
+                      gateway='1.0.0.1',
+                      table=10,
+                      onlink=True,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='2001:db8:2::1/128',
+                      gateway='2001:db8::1',
+                      family=socket.AF_INET6),
+            mock.call(controller.DELETE,
+                      oif=idx,
+                      dst='24.24.0.0/16',
+                      gateway='2.0.0.254',
+                      prefsrc='2.0.0.1',
+                      table=254,
+                      family=socket.AF_INET)])
+
+        mock_rule.assert_has_calls([
+            mock.call(controller.ADD,
+                      src="2001:db8::1",
+                      src_len=128,
+                      table=40,
+                      family=socket.AF_INET6),
+            mock.call(controller.DELETE,
+                      src='3.3.3.3',
+                      src_len=32,
+                      table=254,
+                      family=socket.AF_INET)])
+
+        mock_check_output.assert_has_calls([
+            mock.call(["post-up", "eth1"])
+        ])
+
+    @mock.patch('pyroute2.IPRoute.rule')
+    @mock.patch('pyroute2.IPRoute.route')
+    @mock.patch('pyroute2.IPRoute.addr')
+    @mock.patch('pyroute2.IPRoute.link')
+    @mock.patch('pyroute2.IPRoute.get_links')
+    @mock.patch('pyroute2.IPRoute.get_rules')
+    @mock.patch('pyroute2.IPRoute.get_routes')
+    @mock.patch('pyroute2.IPRoute.get_addr')
     @mock.patch('pyroute2.IPRoute.link_lookup')
     @mock.patch('subprocess.check_output')
     @mock.patch('octavia.amphorae.backends.utils.interface.'
                 'InterfaceController._wait_tentative')
     def test_up_auto(self, mock_wait_tentative, mock_check_output,
-                     mock_link_lookup, mock_link, mock_addr, mock_route,
-                     mock_rule):
+                     mock_link_lookup, mock_get_addr, mock_get_routes,
+                     mock_get_rules, mock_get_links, mock_link, mock_addr,
+                     mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.DHCP: True,
@@ -472,6 +901,10 @@ class TestInterface(base.TestCase):
         idx = mock.MagicMock()
         mock_link_lookup.return_value = [idx]
 
+        mock_get_links.return_value = [{
+            consts.STATE: consts.IFACE_DOWN
+        }]
+
         controller = interface.InterfaceController()
         controller.up(iface)
 
@@ -513,6 +946,7 @@ class TestInterface(base.TestCase):
                   mock_link, mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -629,15 +1063,17 @@ class TestInterface(base.TestCase):
     @mock.patch('pyroute2.IPRoute.rule')
     @mock.patch('pyroute2.IPRoute.route')
     @mock.patch('pyroute2.IPRoute.addr')
+    @mock.patch('pyroute2.IPRoute.flush_addr')
     @mock.patch('pyroute2.IPRoute.link')
     @mock.patch('pyroute2.IPRoute.get_links')
     @mock.patch('pyroute2.IPRoute.link_lookup')
     @mock.patch('subprocess.check_output')
     def test_down_with_errors(self, mock_check_output, mock_link_lookup,
-                              mock_get_links, mock_link, mock_addr,
-                              mock_route, mock_rule):
+                              mock_get_links, mock_link, mock_flush_addr,
+                              mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -690,6 +1126,9 @@ class TestInterface(base.TestCase):
         mock_addr.side_effect = [
             pyroute2.NetlinkError(123),
             pyroute2.NetlinkError(123),
+            pyroute2.NetlinkError(123),
+        ]
+        mock_flush_addr.side_effect = [
             pyroute2.NetlinkError(123)
         ]
         mock_route.side_effect = [
@@ -731,6 +1170,10 @@ class TestInterface(base.TestCase):
                       family=socket.AF_INET6)
         ])
 
+        mock_flush_addr.assert_has_calls([
+            mock.call(index=idx)
+        ])
+
         mock_route.assert_has_calls([
             mock.call(controller.DELETE,
                       oif=idx,
@@ -780,6 +1223,7 @@ class TestInterface(base.TestCase):
                                mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -842,15 +1286,17 @@ class TestInterface(base.TestCase):
     @mock.patch('pyroute2.IPRoute.rule')
     @mock.patch('pyroute2.IPRoute.route')
     @mock.patch('pyroute2.IPRoute.addr')
+    @mock.patch('pyroute2.IPRoute.flush_addr')
     @mock.patch('pyroute2.IPRoute.link')
     @mock.patch('pyroute2.IPRoute.get_links')
     @mock.patch('pyroute2.IPRoute.link_lookup')
     @mock.patch('subprocess.check_output')
     def test_down_auto(self, mock_check_output, mock_link_lookup,
-                       mock_get_links, mock_link, mock_addr, mock_route,
-                       mock_rule):
+                       mock_get_links, mock_link, mock_flush_addr,
+                       mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.DHCP: True,
@@ -886,6 +1332,8 @@ class TestInterface(base.TestCase):
         mock_route.assert_not_called()
         mock_rule.assert_not_called()
 
+        mock_flush_addr.assert_called_once()
+
         mock_check_output.assert_has_calls([
             mock.call(["/sbin/dhclient",
                        "-r",
@@ -950,3 +1398,102 @@ class TestInterface(base.TestCase):
 
         controller._wait_tentative(mock_ipr, idx)
         self.assertEqual(4, len(mock_time_sleep.mock_calls))
+
+    def test__normalize_ip_address(self):
+        controller = interface.InterfaceController()
+
+        # Simple IPv4 address
+        addr = controller._normalize_ip_address('192.168.0.1')
+        self.assertEqual('192.168.0.1', addr)
+
+        # Simple IPv6 address
+        addr = controller._normalize_ip_address('2001::1')
+        self.assertEqual('2001::1', addr)
+
+        # Uncompressed IPv6 address
+        addr = controller._normalize_ip_address(
+            '2001:0000:0000:0000:0000:0000:0000:0001')
+        self.assertEqual('2001::1', addr)
+
+        addr = controller._normalize_ip_address(None)
+        self.assertIsNone(addr)
+
+    def test__normalize_ip_network(self):
+        controller = interface.InterfaceController()
+
+        # Simple IP address
+        addr = controller._normalize_ip_network('192.168.0.1')
+        self.assertEqual('192.168.0.1/32', addr)
+
+        # "Normal" network
+        addr = controller._normalize_ip_network('10.0.0.0/16')
+        self.assertEqual('10.0.0.0/16', addr)
+
+        # Network with hostbits set
+        addr = controller._normalize_ip_network('10.0.0.10/16')
+        self.assertEqual('10.0.0.0/16', addr)
+
+        # IPv6 network with hostbits set
+        addr = controller._normalize_ip_network('2001::1/64')
+        self.assertEqual('2001::/64', addr)
+
+        # Uncompressed IPv6 network
+        addr = controller._normalize_ip_network(
+            '2001:0000:0000:0000:0000:0000:0000:0001/64')
+        self.assertEqual('2001::/64', addr)
+
+        addr = controller._normalize_ip_network(None)
+        self.assertIsNone(addr)
+
+    @mock.patch('octavia.amphorae.backends.utils.nftable_utils.'
+                'load_nftables_file')
+    @mock.patch('octavia.amphorae.backends.utils.nftable_utils.'
+                'write_nftable_vip_rules_file')
+    @mock.patch('subprocess.check_output')
+    def test__setup_nftables_chain(self, mock_check_output, mock_write_rules,
+                                   mock_load_rules):
+
+        controller = interface.InterfaceController()
+
+        mock_check_output.side_effect = [
+            mock.DEFAULT, mock.DEFAULT,
+            subprocess.CalledProcessError(cmd=consts.NFT_CMD, returncode=-1),
+            mock.DEFAULT,
+            subprocess.CalledProcessError(cmd=consts.NFT_CMD, returncode=-1)]
+
+        interface_mock = mock.MagicMock()
+        interface_mock.name = 'fake2'
+
+        # Test succeessful path
+        controller._setup_nftables_chain(interface_mock)
+
+        mock_write_rules.assert_called_once_with('fake2', [])
+        mock_load_rules.assert_called_once_with()
+        mock_check_output.assert_has_calls([
+            mock.call([consts.NFT_CMD, 'add', 'table', consts.NFT_FAMILY,
+                       consts.NFT_VIP_TABLE], stderr=subprocess.STDOUT),
+            mock.call([consts.NFT_CMD, 'add', 'chain', consts.NFT_FAMILY,
+                       consts.NFT_VIP_TABLE, consts.NFT_VIP_CHAIN, '{',
+                       'type', 'filter', 'hook', 'ingress', 'device',
+                       'fake2', 'priority', consts.NFT_SRIOV_PRIORITY, ';',
+                       'policy', 'drop', ';', '}'], stderr=subprocess.STDOUT)])
+
+        # Test first nft call fails
+        mock_write_rules.reset_mock()
+        mock_load_rules.reset_mock()
+        mock_check_output.reset_mock()
+
+        self.assertRaises(subprocess.CalledProcessError,
+                          controller._setup_nftables_chain, interface_mock)
+        mock_check_output.assert_called_once()
+        mock_write_rules.assert_not_called()
+
+        # Test second nft call fails
+        mock_write_rules.reset_mock()
+        mock_load_rules.reset_mock()
+        mock_check_output.reset_mock()
+
+        self.assertRaises(subprocess.CalledProcessError,
+                          controller._setup_nftables_chain, interface_mock)
+        self.assertEqual(2, mock_check_output.call_count)
+        mock_write_rules.assert_not_called()
