@@ -25,6 +25,8 @@ from octavia.common import rpc
 # needed for tests to function when run independently:
 from octavia.common import config  # noqa: F401
 
+from octavia.tests import fixtures as oc_fixtures
+
 
 class TestCase(testtools.TestCase):
 
@@ -34,6 +36,8 @@ class TestCase(testtools.TestCase):
         self.addCleanup(mock.patch.stopall)
         self.addCleanup(self.clean_caches)
 
+        self.warning_fixture = self.useFixture(oc_fixtures.WarningsFixture())
+
     def clean_caches(self):
         clients.NovaAuth.nova_client = None
         clients.NeutronAuth.neutron_client = None
@@ -44,6 +48,8 @@ class TestRpc(testtools.TestCase):
         super().__init__(*args, **kwargs)
         self._buses = {}
 
+        self.warning_fixture = self.useFixture(oc_fixtures.WarningsFixture())
+
     def _fake_create_transport(self, url):
         if url not in self._buses:
             self._buses[url] = messaging.get_rpc_transport(
